@@ -21,41 +21,41 @@
 #include <cstdlib>
 #include <cstring>
 #include <iostream>
+#include <stdexcept>
 
 #include "RKF32.h"
-#include "log.h"
+// #include "log.h"
 #include "types.h"
 
 using namespace goss;
 
 //-----------------------------------------------------------------------------
 RKF32::RKF32()
-    : AdaptiveExplicitSolver(), nfevals(0), ndtsa(0), ndtsr(0), a21(1.0 / 2.0), a32(3.0 / 4.0),
-      b1(2.0 / 9.0), b2(1.0 / 3.0), b3(4.0 / 9.0), bh1(7.0 / 24.0), bh2(1.0 / 4.0), bh3(1.0 / 3.0),
-      bh4(1.0 / 8.0), d1(b1 - bh1), d2(b2 - bh2), d3(b3 - bh3), d4(-bh4), c2(1.0 / 2.0),
-      c3(3.0 / 4.0), nbytes(0), ki(0), k1(0), k2(0), k3(0), k4(0), yn(0), e(0)
+    : AdaptiveExplicitSolver(), nfevals(0), ndtsa(0), ndtsr(0), a21(1.0 / 2.0), a32(3.0 / 4.0), b1(2.0 / 9.0),
+      b2(1.0 / 3.0), b3(4.0 / 9.0), bh1(7.0 / 24.0), bh2(1.0 / 4.0), bh3(1.0 / 3.0), bh4(1.0 / 8.0), d1(b1 - bh1),
+      d2(b2 - bh2), d3(b3 - bh3), d4(-bh4), c2(1.0 / 2.0), c3(3.0 / 4.0), nbytes(0), ki(0), k1(0), k2(0), k3(0), k4(0),
+      yn(0), e(0)
 {
     _iord = 3;
 }
 //-----------------------------------------------------------------------------
 RKF32::RKF32(std::shared_ptr<ODE> ode)
-    : AdaptiveExplicitSolver(), nfevals(0), ndtsa(0), ndtsr(0), a21(1.0 / 2.0), a32(3.0 / 4.0),
-      b1(2.0 / 9.0), b2(1.0 / 3.0), b3(4.0 / 9.0), bh1(7.0 / 24.0), bh2(1.0 / 4.0), bh3(1.0 / 3.0),
-      bh4(1.0 / 8.0), d1(b1 - bh1), d2(b2 - bh2), d3(b3 - bh3), d4(-bh4), c2(1.0 / 2.0),
-      c3(3.0 / 4.0), nbytes(0), ki(0), k1(0), k2(0), k3(0), k4(0), yn(0), e(0)
+    : AdaptiveExplicitSolver(), nfevals(0), ndtsa(0), ndtsr(0), a21(1.0 / 2.0), a32(3.0 / 4.0), b1(2.0 / 9.0),
+      b2(1.0 / 3.0), b3(4.0 / 9.0), bh1(7.0 / 24.0), bh2(1.0 / 4.0), bh3(1.0 / 3.0), bh4(1.0 / 8.0), d1(b1 - bh1),
+      d2(b2 - bh2), d3(b3 - bh3), d4(-bh4), c2(1.0 / 2.0), c3(3.0 / 4.0), nbytes(0), ki(0), k1(0), k2(0), k3(0), k4(0),
+      yn(0), e(0)
 {
     _iord = 3;
     attach(ode);
 }
 //-----------------------------------------------------------------------------
 RKF32::RKF32(const RKF32 &solver)
-    : AdaptiveExplicitSolver(solver), nfevals(solver.nfevals), ndtsa(solver.ndtsa),
-      ndtsr(solver.ndtsr), a21(1.0 / 2.0), a32(3.0 / 4.0), b1(2.0 / 9.0), b2(1.0 / 3.0),
-      b3(4.0 / 9.0), bh1(7.0 / 24.0), bh2(1.0 / 4.0), bh3(1.0 / 3.0), bh4(1.0 / 8.0), d1(b1 - bh1),
-      d2(b2 - bh2), d3(b3 - bh3), d4(-bh4), c2(1.0 / 2.0), c3(3.0 / 4.0),
-      nbytes(solver.num_states() * sizeof(double)), ki(solver.num_states()),
-      k1(solver.num_states()), k2(solver.num_states()), k3(solver.num_states()),
-      k4(solver.num_states()), yn(solver.num_states()), e(solver.num_states())
+    : AdaptiveExplicitSolver(solver), nfevals(solver.nfevals), ndtsa(solver.ndtsa), ndtsr(solver.ndtsr), a21(1.0 / 2.0),
+      a32(3.0 / 4.0), b1(2.0 / 9.0), b2(1.0 / 3.0), b3(4.0 / 9.0), bh1(7.0 / 24.0), bh2(1.0 / 4.0), bh3(1.0 / 3.0),
+      bh4(1.0 / 8.0), d1(b1 - bh1), d2(b2 - bh2), d3(b3 - bh3), d4(-bh4), c2(1.0 / 2.0), c3(3.0 / 4.0),
+      nbytes(solver.num_states() * sizeof(double)), ki(solver.num_states()), k1(solver.num_states()),
+      k2(solver.num_states()), k3(solver.num_states()), k4(solver.num_states()), yn(solver.num_states()),
+      e(solver.num_states())
 {
     // Do nothing
 }
@@ -73,8 +73,8 @@ void RKF32::attach(std::shared_ptr<ODE> ode)
     ODESolver::attach(ode);
 
     if (ode->is_dae())
-        goss_error("RKF32.cpp", "attaching ode",
-                   "cannot integrate a DAE ode with an explicit solver.");
+        // goss_error("RKF32.cpp", "attaching ode", "cannot integrate a DAE ode with an explicit solver.");
+        throw std::runtime_error("cannot integrate a DAE ode with an explicit solver.");
 
     // Initilize RK increments
     ki.resize(num_states());
@@ -124,16 +124,20 @@ void RKF32::forward(double *y, double t, double interval)
     _t = t;
 
     // FIXME: first i always true
-    if (first) {
+    if (first)
+    {
         _ode->eval(y, t, &k1[0]);
         nfevals += 1;
     }
 
     // Set initial time step
-    if (_ldt < 0) {
+    if (_ldt < 0)
+    {
         _dt = dtinit(t, y, yn0, &k1[0], &k2[0], _iord);
         nfevals += 1;
-    } else {
+    }
+    else
+    {
         _dt = _ldt;
     }
 
@@ -142,7 +146,8 @@ void RKF32::forward(double *y, double t, double interval)
     dt_v.push_back(_dt);
 #endif
 
-    while (!reached_tend) {
+    while (!reached_tend)
+    {
 
         for (i = 0; i < num_states(); ++i)
             ki[i] = y[i] + _dt * a21 * k1[i];
@@ -157,7 +162,7 @@ void RKF32::forward(double *y, double t, double interval)
         // We assemble the new y
         for (i = 0; i < num_states(); ++i)
             yn0[i] = y[i] + _dt * (b1 * k1[i] + b2 * k2[i] + b3 * k3[i]);
-        //yn[i] = y[i] + _dt*(bh1*k1[i]+bh2*k2[i]+bh3*k3[i]+bh4*k4[i]);
+        // yn[i] = y[i] + _dt*(bh1*k1[i]+bh2*k2[i]+bh3*k3[i]+bh4*k4[i]);
 
         // We compute the first quadrature node for the next iteration (FSAL)
         _ode->eval(yn0, t + _dt, &k4[0]);
@@ -175,34 +180,39 @@ void RKF32::forward(double *y, double t, double interval)
 #endif
 
         // If step
-        if (step_accepted) {
+        if (step_accepted)
+        {
             ndtsa += 1;
             swap = y;
             y = yn0;
             yn0 = swap;
             k4.swap(k1);
 #ifdef DEBUG
-            if (single_step_mode) {
-                if (ret_ptr != y) {
+            if (single_step_mode)
+            {
+                if (ret_ptr != y)
+                {
                     for (i = 0; i < num_states(); ++i)
                         ret_ptr[i] = y[i];
-                    //memcpy(ret_ptr, y, nbytes);
+                    // memcpy(ret_ptr, y, nbytes);
                     yn0 = y;
                 }
                 swap = 0;
                 return;
             }
 #endif
-        } else
+        }
+        else
             ndtsr += 1;
     }
 
     // This is a copy to ensure that the input Ptr contains the final solution
     // This can probably be done in a more elegant way
-    if (ret_ptr != y) {
+    if (ret_ptr != y)
+    {
         for (i = 0; i < num_states(); ++i)
             ret_ptr[i] = y[i];
-        //memcpy(ret_ptr, y, nbytes);
+        // memcpy(ret_ptr, y, nbytes);
         yn0 = y;
     }
 
